# Generated by roxygen2: do not edit by hand

export("%>%")
export(easytable)
export(format_latex)
export(format_word)
importFrom(dplyr,.data)
importFrom(dplyr,across)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,filter)
importFrom(dplyr,full_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,where)
importFrom(magrittr,"%>%")
importFrom(stats,nobs)
importFrom(utils,write.csv)
