#' Pipe Operator
#'
#' Re-export of `%>%` from 'magrittr'.
#'
#' @name %>%
#' @rdname pipe
#' @keywords internal
#' @return The result of evaluating the right-hand side expression after the
#'   left-hand side has been passed through the pipe.
#' @importFrom magrittr %>%
#' @export
magrittr::`%>%`
