% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/transform_table.R
\name{deduplicate_control_vars}
\alias{deduplicate_control_vars}
\title{Remove duplicate control variable rows}
\usage{
deduplicate_control_vars(table)
}
\arguments{
\item{table}{A data frame with regression results}
}
\value{
A data frame with duplicates removed
}
\description{
After collapsing control variables, removes duplicate rows but keeps
one representative row per control variable for each model.
}
\keyword{internal}
