% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/validators.R
\name{validate_control_vars}
\alias{validate_control_vars}
\title{Validate control variables exist in models}
\usage{
validate_control_vars(model_list, control.var)
}
\arguments{
\item{model_list}{A named list of models}

\item{control.var}{Character vector of control variable names}
}
\value{
Invisible TRUE if valid, otherwise stops with error
}
\description{
Validate control variables exist in models
}
\keyword{internal}
