% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/transform_table.R
\name{transform_table}
\alias{transform_table}
\title{Transform parsed model table}
\usage{
transform_table(parsed_table, control.var = NULL, abbreviate = FALSE)
}
\arguments{
\item{parsed_table}{A data frame from parse_models()}

\item{control.var}{Character vector of control variable names}

\item{abbreviate}{Logical. Abbreviate variable names? Default FALSE}
}
\value{
A transformed data frame ready for formatting
}
\description{
Main transformation function that handles control variables, sorting,
deduplication, organization, and term label formatting.
}
\keyword{internal}
