% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/validators.R
\name{validate_custom_row}
\alias{validate_custom_row}
\title{Validate custom.row parameter}
\usage{
validate_custom_row(custom.row, n_models)
}
\arguments{
\item{custom.row}{Character vector or NULL}

\item{n_models}{Integer number of models in the table}
}
\value{
Invisible TRUE if valid, otherwise stops with error
}
\description{
Validate custom.row parameter
}
\keyword{internal}
