% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/validators.R
\name{validate_model_list}
\alias{validate_model_list}
\title{Validate model list input}
\usage{
validate_model_list(model_list)
}
\arguments{
\item{model_list}{A named list of models}
}
\value{
Invisible TRUE if valid, otherwise stops with error
}
\description{
Validate model list input
}
\keyword{internal}
