% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/transform_table.R
\name{collapse_control_vars}
\alias{collapse_control_vars}
\title{Collapse control variable rows}
\usage{
collapse_control_vars(table, control.var, levels_map = NULL)
}
\arguments{
\item{table}{A data frame with regression results}

\item{control.var}{Character vector of control variable names to collapse}
}
\value{
A data frame with collapsed control variables
}
\description{
Collapses multiple rows for control variables (including factor levels and
transformations) into a single row per control variable.
}
\keyword{internal}
