% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/validators.R
\name{validate_table_size}
\alias{validate_table_size}
\title{Validate table_size parameter}
\usage{
validate_table_size(table_size, output)
}
\arguments{
\item{table_size}{Character string specifying LaTeX table size}

\item{output}{Character string specifying output format}
}
\value{
Invisible TRUE if valid, otherwise stops with error
}
\description{
Validate table_size parameter
}
\keyword{internal}
