% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{get_first_measure_row}
\alias{get_first_measure_row}
\title{Get first model statistic row index}
\usage{
get_first_measure_row(table)
}
\description{
Get first model statistic row index
}
\keyword{internal}
