% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/parse_models.R
\name{extract_model_measures}
\alias{extract_model_measures}
\title{Extract goodness-of-fit measures from a model}
\usage{
extract_model_measures(model)
}
\arguments{
\item{model}{A statistical model object (lm or glm)}
}
\value{
A data frame with model fit statistics
}
\description{
Rounding is fixed per statistic and independent of the user-facing \code{digits}
option: N = 0, R sq. = 2, Adj. R sq. = 2, AIC = 0. AIC is only reported
for \code{glm} models.
}
\keyword{internal}
