% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/validators.R
\name{check_robust_dependencies}
\alias{check_robust_dependencies}
\title{Check robust SE dependencies}
\usage{
check_robust_dependencies(robust.se)
}
\arguments{
\item{robust.se}{Logical indicating if robust SEs are requested}
}
\value{
Invisible TRUE if dependencies available, otherwise stops with error
}
\description{
Check robust SE dependencies
}
\keyword{internal}
