% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/parse_models.R
\name{tidy_coeftest}
\alias{tidy_coeftest}
\title{Extract tidy coefficients from a coeftest matrix}
\usage{
tidy_coeftest(x)
}
\arguments{
\item{x}{A coeftest object from lmtest::coeftest()}
}
\value{
A data frame with columns: term, estimate, std.error, p.value
}
\description{
Extract tidy coefficients from a coeftest matrix
}
\keyword{internal}
